SCUM
------

Scum is a terminal-based, multi-tab text editor written in Python.

.. figure:: https://github.com/CCareaga/scum/blob/master/src/docs/scum.gif?raw=true
   :alt: Scum in urxvt!

About
---------

First of all, Scum is really just a novelty editor I wrote mostly for
learning and fun. It was not made to compete with seasoned text editors
such as Emacs or Vim (hence the name "Scum"). With that being said, it
is still a fully-functional terminal based editor! It can be used for
both quick editing and full on development. Overall it was extremely fun
to write and was a wonderful learning experience. Enjoy! (at your own
risk)

Features
------------

-  Syntax-highlighting
-  Multiple Tabs
-  Undo and find functions
-  Open and save files (complete with text-based file-browser)
-  Fully customizable
-  On-the-go configuration changing
-  Tab saving
-  Togglable line numbers and terminal

Dependencies
----------------

-  Python 3.x
-  Urwid
-  Pygments

To-Do
---------

-  Find and replace.
-  Creating a new file.

Key Bindings
----------------

+------------------+------------------------+
| Key:             | Command:               |
+==================+========================+
| Ctrl+O           | Open file(s)           |
+------------------+------------------------+
| Ctrl+S           | Save file              |
+------------------+------------------------+
| Ctrl+W           | Close current tab      |
+------------------+------------------------+
| Ctrl+page up     | Move to the next tab   |
+------------------+------------------------+
| Ctrl+page down   | Move to the prev tab   |
+------------------+------------------------+
| F5               | Edit the config file   |
+------------------+------------------------+
| F1               | Change GUI layout      |
+------------------+------------------------+
| Ctrl+F           | Find                   |
+------------------+------------------------+
| Ctrl+Q           | Undo last action       |
+------------------+------------------------+
| Ctrl+D           | Delete current line    |
+------------------+------------------------+
| Ctrl+X           | Exit                   |
+------------------+------------------------+
